==> 0.0.32.tar.gz: lib/widgets/media.dart <==
import 'package:feed_plugin/utilities/social_media.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:url_launcher/url_launcher.dart';

class MediaPage extends StatefulWidget {
  const MediaPage({
    Key key,
    this.whatsapp,
    this.facebook,
    this.instagram,
    this.twitter,
    this.linkedin,
    this.youtube,
    this.tiktok,
  }) : super(key: key);

  final String whatsapp;
  final String facebook;
  final String instagram;
  final String twitter;
  final String linkedin;
  final String youtube;
  final String tiktok;

  @override
  _MediaPageState createState() => _MediaPageState();
}

class _MediaPageState extends State<MediaPage> {
  List<String> row1;
  List<String> row2;

  List<String> socialMediaName;
  List<String> socialMediaUrl;
  List<String> socialMediaImg;

  initSocialMedia() async {
    var mediaData = this.widget;
    socialMediaUrl = [
      mediaData.whatsapp,
      mediaData.facebook,
      mediaData.instagram,
      mediaData.twitter,
      mediaData.linkedin,
      mediaData.youtube,
      mediaData.tiktok,
    ];
    socialMediaName = [
      "whatsapp",
      "facebook",
      "instagram",
      "twitter",
      "linkedin",
      "youtube",
      "tiktok",
    ];
    socialMediaImg = [
      whatsapp,
      facebook,
      instagram,
      twitter,
      linkedin,
      youtube,
      tiktok,
    ];

    List<String> img = socialMediaImg;
    List<String> name = socialMediaName;
    List<String> url = socialMediaUrl;

    socialMediaImg = [];
    socialMediaName = [];
    socialMediaUrl = [];

    for (var i = 0; i < 7; i++) {
      if (url[i] != null && url[i] != "false") {
        socialMediaImg.add(img[i]);
        socialMediaName.add(name[i]);
        socialMediaUrl.add(url[i]);
      }
    }
  }

  _gagv() {
    List<Widget> children1 = [];
    List<Widget> children2 = [];

    for (var i = 0; i < socialMediaUrl.length; i++) {
      if (i < 4 && row1.length < 4 && row1.length < socialMediaImg.length) {
        row1.add(socialMediaImg[i]);
      } else if (row2.length < 3 && row2.length < socialMediaImg.length - 4) {
        row2.add(socialMediaImg[i]);
      }
    }

    for (var i = 0; i < row1.length; i++) {
      var e = Expanded(
        child: Column(
          children: [
            SizedBox(
              // width: ScreenUtil().setHeight(25),
              // height: ScreenUtil().setHeight(25),
              child: MaterialButton(
                onPressed: () {
                  if (socialMediaName[i] == "whatsapp") {
                    var str = socialMediaUrl[i].split('-');
                    socialMediaUrl[i] = "";
                    str.forEach((j) {
                      socialMediaUrl[i] += j;
                    });
                    launch(
                        "http://api.whatsapp.com/send?phone=${socialMediaUrl[i]}");
                  } else {
                    launch(socialMediaUrl[i]);
                  }
                },
                child: Image.network(
                  row1[i],
                  width: ScreenUtil().setHeight(25),
                  height: ScreenUtil().setHeight(25),
                ),
              ),
            ),
            Text(socialMediaName[i])
          ],
        ),
      );
      children1.add(e);
    }
    if (row2.length > 0) {
      for (var i = 0; i < 4; i++) {
        var e = Expanded(
          child: Padding(
            padding: EdgeInsets.only(top: ScreenUtil().setHeight(10)),
            child: Column(
              children: [
                SizedBox(
                    child: row2.length - 1 >= i
                        ? MaterialButton(
                            onPressed: () {
                              if (socialMediaName[4 + i] == "whatsapp") {
                                var str = socialMediaUrl[4 + i].split('-');
                                socialMediaUrl[4 + i] = "";
                                str.forEach((j) {
                                  socialMediaUrl[4 + i] += j;
                                });

                                launch(
                                    "http://api.whatsapp.com/send?phone=${socialMediaUrl[4 + i]}");
                              } else {
                                launch(socialMediaUrl[4 + i]);
                              }
                            },
                            child: Image.network(
                              row2[i],
                              width: ScreenUtil().setHeight(25),
                              height: ScreenUtil().setHeight(25),
                            ))
                        : Image.network(
                            row2[0],
                            color: Colors.white,
                            width: ScreenUtil().setHeight(25),
                            height: ScreenUtil().setHeight(25),
                          )),
                row2.length - 1 >= i ? Text(socialMediaName[4 + i]) : Text("")
              ],
            ),
          ),
        );
        children2.add(e);
      }
    }
    return ListView(
        children: [Row(children: children1), Row(children: children2)]);
  }

  @override
  void initState() {
    super.initState();
    row1 = [];
    row2 = [];
    initSocialMedia();
  }

  @override
  Widget build(BuildContext context) {
    // void _showButtonPressDialog(BuildContext context, String provider) {
    //   // Scaffold.of(context).showSnackBar(SnackBar(
    //   // content: Text('$provider Button Pressed!'),
    //   // backgroundColor: Colors.black26,
    //   // duration: Duration(milliseconds: 400),
    //   //   ));
    // }
    return Container(
      margin: EdgeInsets.only(top: ScreenUtil().setHeight(2)),
      color: Colors.white,
      height: ScreenUtil().setHeight(155),
      child: Padding(
        padding: EdgeInsets.only(
          top: ScreenUtil().setHeight(12),
        ),
        child: _gagv(),
      ),
    );
  }
}

==> 0.0.54.tar.gz: lib/widgets/media.dart <==
import 'package:feed_plugin/utilities/social_media.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:url_launcher/url_launcher.dart';

class MediaPage extends StatefulWidget {
  const MediaPage({
    Key key,
    this.whatsapp,
    this.facebook,
    this.instagram,
    this.twitter,
    this.linkedin,
    this.youtube,
    this.tiktok,
    this.loc,
  }) : super(key: key);

  final String whatsapp;
  final String facebook;
  final String instagram;
  final String twitter;
  final String linkedin;
  final String youtube;
  final String tiktok;
  final loc;
  @override
  _MediaPageState createState() => _MediaPageState();
}

class _MediaPageState extends State<MediaPage> {
  List<String> row1;
  List<String> row2;

  List<String> socialMediaName;
  List<String> socialMediaUrl;
  List<String> socialMediaImg;

  initSocialMedia() async {
    var mediaData = this.widget;
    socialMediaUrl = [
      mediaData.whatsapp,
      mediaData.facebook,
      mediaData.instagram,
      mediaData.twitter,
      mediaData.linkedin,
      mediaData.youtube,
      mediaData.tiktok,
    ];
    socialMediaName = [
      "whatsapp",
      "facebook",
      "instagram",
      "twitter",
      "linkedin",
      "youtube",
      "tiktok",
    ];
    socialMediaImg = [
      whatsapp,
      facebook,
      instagram,
      twitter,
      linkedin,
      youtube,
      tiktok,
    ];

    List<String> img = socialMediaImg;
    List<String> name = socialMediaName;
    List<String> url = socialMediaUrl;

    socialMediaImg = [];
    socialMediaName = [];
    socialMediaUrl = [];

    for (var i = 0; i < 7; i++) {
      if (url[i] != null && url[i] != "false") {
        socialMediaImg.add(img[i]);
        socialMediaName.add(name[i]);
        socialMediaUrl.add(url[i]);
      }
    }
  }

  _gagv() {
    List<Widget> children1 = [];
    List<Widget> children2 = [];

    for (var i = 0; i < socialMediaUrl.length; i++) {
      if (i < 4 && row1.length < 4 && row1.length < socialMediaImg.length) {
        row1.add(socialMediaImg[i]);
      } else if (row2.length < 3 && row2.length < socialMediaImg.length - 4) {
        row2.add(socialMediaImg[i]);
      }
    }

    for (var i = 0; i < row1.length; i++) {
      var e = Expanded(
        child: Column(
          children: [
            SizedBox(
              // width: ScreenUtil().setHeight(25),
              // height: ScreenUtil().setHeight(25),
              child: MaterialButton(
                onPressed: () {
                  if (socialMediaName[i] == "whatsapp") {
                    var str = socialMediaUrl[i].split('-');
                    socialMediaUrl[i] = "";
                    str.forEach((j) {
                      socialMediaUrl[i] += j;
                    });
                    launch(
                        "http://api.whatsapp.com/send?phone=${socialMediaUrl[i]}");
                  } else {
                    launch(socialMediaUrl[i]);
                  }
                },
                child: Image.network(
                  row1[i],
                  width: ScreenUtil().setHeight(35),
                  height: ScreenUtil().setHeight(35),
                ),
              ),
            ),
            Text(this.widget.loc.translate(socialMediaName[i]))
          ],
        ),
      );
      children1.add(e);
    }
    if (row2.length > 0) {
      for (var i = 0; i < 4; i++) {
        var e = Expanded(
          child: Padding(
            padding: EdgeInsets.only(top: ScreenUtil().setHeight(10)),
            child: Column(
              children: [
                SizedBox(
                    child: row2.length - 1 >= i
                        ? MaterialButton(
                            onPressed: () {
                              if (socialMediaName[4 + i] == "whatsapp") {
                                var str = socialMediaUrl[4 + i].split('-');
                                socialMediaUrl[4 + i] = "";
                                str.forEach((j) {
                                  socialMediaUrl[4 + i] += j;
                                });

                                launch(
                                    "http://api.whatsapp.com/send?phone=${socialMediaUrl[4 + i]}");
                              } else {
                                launch(socialMediaUrl[4 + i]);
                              }
                            },
                            child: Image.network(
                              row2[i],
                              width: ScreenUtil().setHeight(35),
                              height: ScreenUtil().setHeight(35),
                            ))
                        : Image.network(
                            row2[0],
                            color: Colors.white,
                            width: ScreenUtil().setHeight(35),
                            height: ScreenUtil().setHeight(35),
                          )),
                row2.length - 1 >= i
                    ? Text(this.widget.loc.translate(socialMediaName[4 + i]))
                    : Text("")
              ],
            ),
          ),
        );
        children2.add(e);
      }
    }
    return ListView(
        physics: const NeverScrollableScrollPhysics(),
        children: [Row(children: children1), Row(children: children2)]);
  }

  @override
  void initState() {
    super.initState();
    row1 = [];
    row2 = [];
    initSocialMedia();
  }

  @override
  Widget build(BuildContext context) {
    // void _showButtonPressDialog(BuildContext context, String provider) {
    //   // Scaffold.of(context).showSnackBar(SnackBar(
    //   // content: Text('$provider Button Pressed!'),
    //   // backgroundColor: Colors.black26,
    //   // duration: Duration(milliseconds: 400),
    //   //   ));
    // }
    return Container(
      margin: EdgeInsets.only(top: ScreenUtil().setHeight(2)),
      color: Colors.white,
      height: ScreenUtil().setHeight(155),
      child: Padding(
        padding: EdgeInsets.only(
          top: ScreenUtil().setHeight(12),
        ),
        child: _gagv(),
      ),
    );
  }
}
